// Copyright 2018 The Oppia Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Service for checking the correctness feedback for an
 * exploration.
 */

import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { downgradeInjectable } from '@angular/upgrade/static';

@Injectable({
  providedIn: 'root'
})
export class ExplorationEditsAllowedBackendApiService {
  constructor(
    private http: HttpClient
  ) {}

  async setEditsAllowed(
      editsAreAllowed: boolean,
      explorationId: string,
      callback: () => void
  ): Promise<void> {
    return this.http.put(`/editsallowedhandler/${explorationId}`, {
      edits_are_allowed: editsAreAllowed
    }).toPromise().then(callback, () => {});
  }
}

angular.module('oppia').factory('ExplorationEditsAllowedBackendApiService',
  downgradeInjectable(ExplorationEditsAllowedBackendApiService));
