// Copyright 2021 The Oppia Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Service for storing all upgraded services
 */

import { downgradeInjectable } from '@angular/upgrade/static';
import { Injectable } from '@angular/core';
import { Meta, Title } from '@angular/platform-browser';
// eslint-disable-next-line oppia/disallow-httpclient
import { HttpClient, HttpXhrBackend,
  // eslint-disable-next-line camelcase, oppia/disallow-flags
  ɵangular_packages_common_http_http_d
} from '@angular/common/http';


import { AdminBackendApiService } from
  'domain/admin/admin-backend-api.service';
import { AdminDataService } from
  'pages/admin-page/services/admin-data.service';
import { AdminRouterService } from
  'pages/admin-page/services/admin-router.service';
import { AdminTaskManagerService } from
  'pages/admin-page/services/admin-task-manager.service';
import { AlertsService } from 'services/alerts.service';
import { AlgebraicExpressionInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/AlgebraicExpressionInput/directives/algebraic-expression-input-rules.service';
import { AlgebraicExpressionInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/AlgebraicExpressionInput/directives/algebraic-expression-input-validation.service';
import { AngularNameService } from
  'pages/exploration-editor-page/services/angular-name.service';
import { AnswerClassificationService } from
  'pages/exploration-player-page/services/answer-classification.service';
import { AnswerGroupObjectFactory } from
  'domain/exploration/AnswerGroupObjectFactory';
import { AppService } from 'services/app.service';
import { AssetsBackendApiService } from
  'services/assets-backend-api.service';
import { AudioBarStatusService } from 'services/audio-bar-status.service';
import { AudioPreloaderService } from
  'pages/exploration-player-page/services/audio-preloader.service';
import { AudioTranslationLanguageService } from
  'pages/exploration-player-page/services/audio-translation-language.service';
import { AudioTranslationManagerService } from
  'pages/exploration-player-page/services/audio-translation-manager.service';
import { AutogeneratedAudioPlayerService } from
  'services/autogenerated-audio-player.service';
import { AutoplayedVideosService } from 'services/autoplayed-videos.service';
import { BackgroundMaskService } from
  'services/stateful/background-mask.service';
import { baseInteractionValidationService } from
  'interactions/base-interaction-validation.service';
import { BottomNavbarStatusService } from
  'services/bottom-navbar-status.service';
import { PreventPageUnloadEventService } from
  'services/prevent-page-unload-event.service';
import { BrowserCheckerService } from
  'domain/utilities/browser-checker.service';
import { CamelCaseToHyphensPipe } from
  'filters/string-utility-filters/camel-case-to-hyphens.pipe';
import { CkEditorCopyContentService } from
  'components/ck-editor-helpers/ck-editor-copy-content.service';
import { ClassifierDataBackendApiService } from
  'services/classifier-data-backend-api.service';
import { ClassroomBackendApiService } from
  'domain/classroom/classroom-backend-api.service';
import { CodeNormalizerService } from 'services/code-normalizer.service';
import { CodeReplRulesService } from
  'interactions/CodeRepl/directives/code-repl-rules.service';
import { CodeReplValidationService } from
  'interactions/CodeRepl/directives/code-repl-validation.service';
import { CollectionCreationBackendService } from
  'components/entity-creation-services/collection-creation-backend-api.service';
import { CollectionCreationService } from
  'components/entity-creation-services/collection-creation.service';
import { CollectionRightsBackendApiService } from
  'domain/collection/collection-rights-backend-api.service';
import { CollectionValidationService } from
  'domain/collection/collection-validation.service';
import { ComputeGraphService } from 'services/compute-graph.service';
import { ConceptCardBackendApiService } from
  'domain/skill/concept-card-backend-api.service';
import { ContextService } from 'services/context.service';
import { ContinueRulesService } from
  'interactions/Continue/directives/continue-rules.service';
import { ContinueValidationService } from
  'interactions/Continue/directives/continue-validation.service';
import { ContributionOpportunitiesBackendApiService } from
  // eslint-disable-next-line max-len
  'pages/contributor-dashboard-page/services/contribution-opportunities-backend-api.service';
import { ConstructTranslationIdsService } from
  'services/construct-translation-ids.service';
import { CountVectorizerService } from 'classifiers/count-vectorizer.service';
import { CreatorDashboardBackendApiService } from
  'domain/creator_dashboard/creator-dashboard-backend-api.service';
import { CsrfTokenService } from 'services/csrf-token.service';
import { CurrentInteractionService } from
  'pages/exploration-player-page/services/current-interaction.service';
import { DateTimeFormatService } from 'services/date-time-format.service';
import { DeviceInfoService } from 'services/contextual/device-info.service';
import { DocumentAttributeCustomizationService } from
  'services/contextual/document-attribute-customization.service';
import { DragAndDropSortInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/DragAndDropSortInput/directives/drag-and-drop-sort-input-rules.service';
import { DragAndDropSortInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/DragAndDropSortInput/directives/drag-and-drop-sort-input-validation.service';
import { EditableCollectionBackendApiService } from
  'domain/collection/editable-collection-backend-api.service';
import { EditabilityService } from 'services/editability.service';
import { EditorFirstTimeEventsService } from
  'pages/exploration-editor-page/services/editor-first-time-events.service';
import { EmailDashboardBackendApiService } from
  'domain/email-dashboard/email-dashboard-backend-api.service';
import { EndExplorationRulesService } from
  'interactions/EndExploration/directives/end-exploration-rules.service';
import { EndExplorationValidationService } from
  'interactions/EndExploration/directives/end-exploration-validation.service';
import { ExplorationDiffService } from
  'pages/exploration-editor-page/services/exploration-diff.service';
import { ExplorationFeaturesBackendApiService } from
  'services/exploration-features-backend-api.service';
import { ExplorationFeaturesService } from
  'services/exploration-features.service';
import { ExplorationHtmlFormatterService } from
  'services/exploration-html-formatter.service';
import { ExplorationImprovementsBackendApiService } from
  'services/exploration-improvements-backend-api.service';
import { ExplorationImprovementsTaskRegistryService } from
  'services/exploration-improvements-task-registry.service';
import { ExplorationObjectFactory } from
  'domain/exploration/ExplorationObjectFactory';
import { ExplorationPermissionsBackendApiService } from
  'domain/exploration/exploration-permissions-backend-api.service';
import { ExplorationRecommendationsBackendApiService } from
  'domain/recommendations/exploration-recommendations-backend-api.service';
import { ExplorationStatsBackendApiService } from
  'services/exploration-stats-backend-api.service';
import { ExplorationStatsService } from 'services/exploration-stats.service';
import { ExpressionEvaluatorService } from
  'expressions/expression-evaluator.service';
import { ExpressionParserService } from 'expressions/expression-parser.service';
import { ExplorationRecommendationsService } from
  // eslint-disable-next-line max-len
  'pages/exploration-player-page/services/exploration-recommendations.service';
import { ExpressionSyntaxTreeService } from
  'expressions/expression-syntax-tree.service';
import { ExtensionTagAssemblerService } from
  'services/extension-tag-assembler.service';
import { ExternalSaveService } from 'services/external-save.service';
import { FeedbackThreadObjectFactory } from
  'domain/feedback_thread/FeedbackThreadObjectFactory';
import { FocusManagerService } from 'services/stateful/focus-manager.service';
import { FractionInputRulesService } from
  'interactions/FractionInput/directives/fraction-input-rules.service';
import { FractionInputValidationService } from
  'interactions/FractionInput/directives/fraction-input-validation.service';
import { GraphDetailService } from
  'interactions/GraphInput/directives/graph-detail.service';
import { GraphInputRulesService } from
  'interactions/GraphInput/directives/graph-input-rules.service';
import { GraphInputValidationService } from
  'interactions/GraphInput/directives/graph-input-validation.service';
import { GraphUtilsService } from
  'interactions/GraphInput/directives/graph-utils.service';
import { GuestCollectionProgressService } from
  'domain/collection/guest-collection-progress.service';
import { HtmlEscaperService } from 'services/html-escaper.service';
import { I18nLanguageCodeService } from 'services/i18n-language-code.service';
import { IdGenerationService } from 'services/id-generation.service';
import { ImageClickInputRulesService } from
  'interactions/ImageClickInput/directives/image-click-input-rules.service';
import { ImageClickInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/ImageClickInput/directives/image-click-input-validation.service';
import { ImprovementsService } from 'services/improvements.service';
import { InteractionAttributesExtractorService } from
  'interactions/interaction-attributes-extractor.service';
import { InteractionDetailsCacheService } from
  // eslint-disable-next-line max-len
  'pages/exploration-editor-page/editor-tab/services/interaction-details-cache.service';
import { InteractionObjectFactory } from
  'domain/exploration/InteractionObjectFactory';
import { InteractionRulesRegistryService } from
  'services/interaction-rules-registry.service';
import { InteractionSpecsService } from 'services/interaction-specs.service';
import { InteractiveMapRulesService } from
  'interactions/InteractiveMap/directives/interactive-map-rules.service';
import { InteractiveMapValidationService } from
  'interactions/InteractiveMap/directives/interactive-map-validation.service';
import { ItemSelectionInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/ItemSelectionInput/directives/item-selection-input-rules.service';
import { ItemSelectionInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/ItemSelectionInput/directives/item-selection-input-validation.service';
import { LanguageUtilService } from 'domain/utilities/language-util.service';
import { LearnerAnswerDetailsBackendApiService } from
  'domain/statistics/learner-answer-details-backend-api.service';
import { LearnerDashboardBackendApiService } from
  'domain/learner_dashboard/learner-dashboard-backend-api.service';
import { LearnerDashboardIdsBackendApiService } from
  'domain/learner_dashboard/learner-dashboard-ids-backend-api.service';
import { LearnerParamsService } from
  'pages/exploration-player-page/services/learner-params.service';
import { LocalStorageService } from 'services/local-storage.service';
import { LoaderService } from 'services/loader.service';
import { LoggerService } from 'services/contextual/logger.service';
import { LostChangeObjectFactory } from
  'domain/exploration/LostChangeObjectFactory';
import { MathEquationInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/MathEquationInput/directives/math-equation-input-rules.service';
import { MathEquationInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/MathEquationInput/directives/math-equation-input-validation.service';
import { MessengerService } from 'services/messenger.service';
import { MetaTagCustomizationService } from
  'services/contextual/meta-tag-customization.service';
import { MisconceptionObjectFactory } from
  'domain/skill/MisconceptionObjectFactory';
import { MultipleChoiceInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/MultipleChoiceInput/directives/multiple-choice-input-rules.service';
import { MultipleChoiceInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/MultipleChoiceInput/directives/multiple-choice-input-validation.service';
import { MusicNotesInputRulesService } from
  'interactions/MusicNotesInput/directives/music-notes-input-rules.service';
import { MusicNotesInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/MusicNotesInput/directives/music-notes-input-validation.service';
import { MusicPhrasePlayerService } from
  // eslint-disable-next-line max-len
  'interactions/MusicNotesInput/directives/music-phrase-player.service';
import { NormalizeWhitespacePipe } from
  'filters/string-utility-filters/normalize-whitespace.pipe';
import { NormalizeWhitespacePunctuationAndCasePipe } from
  // eslint-disable-next-line max-len
  'filters/string-utility-filters/normalize-whitespace-punctuation-and-case.pipe';
import { NumberAttemptsService } from
  'pages/exploration-player-page/services/number-attempts.service';
import { NumericInputRulesService } from
  'interactions/NumericInput/directives/numeric-input-rules.service';
import { NumericInputValidationService } from
  'interactions/NumericInput/directives/numeric-input-validation.service';
import { NumberWithUnitsObjectFactory } from
  'domain/objects/NumberWithUnitsObjectFactory';
import { NumberWithUnitsRulesService } from
  'interactions/NumberWithUnits/directives/number-with-units-rules.service';
import { NumberWithUnitsValidationService } from
  // eslint-disable-next-line max-len
  'interactions/NumberWithUnits/directives/number-with-units-validation.service';
import { NumericExpressionInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/NumericExpressionInput/directives/numeric-expression-input-rules.service';
import { NumericExpressionInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/NumericExpressionInput/directives/numeric-expression-input-validation.service';
import { OutcomeObjectFactory } from 'domain/exploration/OutcomeObjectFactory';
import { PageTitleService } from 'services/page-title.service';
import { ParamChangeObjectFactory } from
  'domain/exploration/ParamChangeObjectFactory';
import { ParamChangesObjectFactory } from
  'domain/exploration/ParamChangesObjectFactory';
import { ParamSpecObjectFactory } from
  'domain/exploration/ParamSpecObjectFactory';
import { ParamSpecsObjectFactory } from
  'domain/exploration/ParamSpecsObjectFactory';
import { ParamTypeObjectFactory } from
  'domain/exploration/ParamTypeObjectFactory';
import { PencilCodeEditorRulesService } from
  'interactions/PencilCodeEditor/directives/pencil-code-editor-rules.service';
import { PencilCodeEditorValidationService } from
  // eslint-disable-next-line max-len
  'interactions/PencilCodeEditor/directives/pencil-code-editor-validation.service';
import { FeatureFlagDummyBackendApiService } from
  'domain/feature-flag/feature-flag-dummy-backend-api.service';
import { PlatformFeatureService } from 'services/platform-feature.service';
import { PlatformParameterAdminBackendApiService } from
  'domain/platform-parameter/platform-parameter-admin-backend-api.service';
import { FeatureFlagBackendApiService } from
  'domain/feature-flag/feature-flag-backend-api.service';
import { PlayerPositionService } from
  'pages/exploration-player-page/services/player-position.service';
import { PlayerTranscriptService } from
  'pages/exploration-player-page/services/player-transcript.service';
import { PlaythroughBackendApiService } from
  'domain/statistics/playthrough-backend-api.service';
import { PlaythroughIssuesBackendApiService } from
  'services/playthrough-issues-backend-api.service';
import { PopulateRuleContentIdsService } from
  'pages/exploration-editor-page/services/populate-rule-content-ids.service';
import { PredictionAlgorithmRegistryService } from
  // eslint-disable-next-line max-len
  'pages/exploration-player-page/services/prediction-algorithm-registry.service';
import { PretestQuestionBackendApiService } from
  'domain/question/pretest-question-backend-api.service';
import { ProfilePageBackendApiService } from
  'pages/profile-page/profile-page-backend-api.service';
import { PythonProgramTokenizer } from 'classifiers/python-program.tokenizer';
import { QuestionBackendApiService } from
  'domain/question/question-backend-api.service';
import { QuestionObjectFactory } from 'domain/question/QuestionObjectFactory';
import { RatingComputationService } from
  'components/ratings/rating-computation/rating-computation.service';
import { RatioExpressionInputRulesService } from
  // eslint-disable-next-line max-len
  'interactions/RatioExpressionInput/directives/ratio-expression-input-rules.service';
import { RatioExpressionInputValidationService } from
  // eslint-disable-next-line max-len
  'interactions/RatioExpressionInput/directives/ratio-expression-input-validation.service';
import { ReadOnlyCollectionBackendApiService } from
  'domain/collection/read-only-collection-backend-api.service';
import { ReadOnlyTopicObjectFactory } from
  'domain/topic_viewer/read-only-topic-object.factory';
import { ReviewTestBackendApiService } from
  'domain/review_test/review-test-backend-api.service';
import { ReviewTestEngineService } from
  'pages/review-test-page/review-test-engine.service';
import { SchemaDefaultValueService } from
  'services/schema-default-value.service';
import { SchemaFormSubmittedService } from
  'services/schema-form-submitted.service';
import { SchemaUndefinedLastElementService } from
  'services/schema-undefined-last-element.service';
import { SearchExplorationsBackendApiService } from
  'domain/collection/search-explorations-backend-api.service';
import { SetInputRulesService } from
  'interactions/SetInput/directives/set-input-rules.service';
import { SetInputValidationService } from
  'interactions/SetInput/directives/set-input-validation.service';
import { SVMPredictionService } from 'classifiers/svm-prediction.service';
import { SidebarStatusService } from 'services/sidebar-status.service';
import { SiteAnalyticsService } from 'services/site-analytics.service';
import { SkillCreationBackendApiService } from
  'domain/skill/skill-creation-backend-api.service';
import { SkillMasteryBackendApiService } from
  'domain/skill/skill-mastery-backend-api.service';
import { SkillObjectFactory } from 'domain/skill/SkillObjectFactory';
import { SkillRightsBackendApiService} from
  'domain/skill/skill-rights-backend-api.service';
import { SolutionObjectFactory } from
  'domain/exploration/SolutionObjectFactory';
import { SolutionValidityService } from
  'pages/exploration-editor-page/editor-tab/services/solution-validity.service';
import { SpeechSynthesisChunkerService } from
  'services/speech-synthesis-chunker.service';
import { StateClassifierMappingService } from
  'pages/exploration-player-page/services/state-classifier-mapping.service';
import { StateContentService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-content.service';
import { StateCustomizationArgsService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-customization-args.service';
import { StateEditorRefreshService } from
  'pages/exploration-editor-page/services/state-editor-refresh.service';
import { StateEditorService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-editor.service';
import { StateGraphLayoutService } from
  'components/graph-services/graph-layout.service';
import { StateHintsService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-hints.service';
import { StateInteractionIdService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-interaction-id.service';
import { StateInteractionStatsBackendApiService } from
  'domain/exploration/state-interaction-stats-backend-api.service';
import { StateInteractionStatsService } from
  'services/state-interaction-stats.service';
import { StateNameService } from
  'components/state-editor/state-editor-properties-services/state-name.service';
import { StateObjectFactory } from 'domain/state/StateObjectFactory';
import { StateParamChangesService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-param-changes.service';
import { StatePropertyService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-property.service';
import { StateRecordedVoiceoversService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-recorded-voiceovers.service';
import { StateSolicitAnswerDetailsService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-solicit-answer-details.service';
import { StateSolutionService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-solution.service';
import { StateTopAnswersStatsBackendApiService } from
  'services/state-top-answers-stats-backend-api.service';
import { StateTopAnswersStatsObjectFactory } from
  'domain/statistics/state-top-answers-stats-object.factory';
import { StateTopAnswersStatsService } from
  'services/state-top-answers-stats.service';
import { StateWrittenTranslationsService } from
  // eslint-disable-next-line max-len
  'components/state-editor/state-editor-properties-services/state-written-translations.service';
import { StatsReportingBackendApiService } from
  'domain/exploration/stats-reporting-backend-api.service';
import { StatesObjectFactory } from 'domain/exploration/StatesObjectFactory';
import { StoryEditorNavigationService } from
  'pages/story-editor-page/services/story-editor-navigation.service';
import { StoryViewerBackendApiService } from
  'domain/story_viewer/story-viewer-backend-api.service';
import { SubtitledUnicodeObjectFactory } from
  'domain/exploration/SubtitledUnicodeObjectFactory';
import { SubtopicViewerBackendApiService } from
  'domain/subtopic_viewer/subtopic-viewer-backend-api.service';
import { SuggestionModalService } from 'services/suggestion-modal.service';
import { SuggestionsService } from 'services/suggestions.service';
import { TextInputPredictionService } from
  'interactions/TextInput/text-input-prediction.service';
import { TextInputRulesService } from
  'interactions/TextInput/directives/text-input-rules.service';
import { TextInputTokenizer } from 'classifiers/text-input.tokenizer';
import { TextInputValidationService } from
  'interactions/TextInput/directives/text-input-validation.service';
import { ThreadStatusDisplayService } from
  // eslint-disable-next-line max-len
  'pages/exploration-editor-page/feedback-tab/services/thread-status-display.service';
import { TopicCreationBackendApiService } from
  'domain/topic/topic-creation-backend-api.service';
import { TopicsAndSkillsDashboardBackendApiService } from
  // eslint-disable-next-line max-len
  'domain/topics_and_skills_dashboard/topics-and-skills-dashboard-backend-api.service';
import { TopicsAndSkillsDashboardPageService } from
  // eslint-disable-next-line max-len
  'pages/topics-and-skills-dashboard-page/topics-and-skills-dashboard-page.service';
import { TopicViewerBackendApiService } from
  'domain/topic_viewer/topic-viewer-backend-api.service';
import { UnitsObjectFactory } from 'domain/objects/UnitsObjectFactory';
import { UrlInterpolationService } from
  'domain/utilities/url-interpolation.service';
import { UrlService } from 'services/contextual/url.service';
import { UserBackendApiService } from 'services/user-backend-api.service';
import { UserService } from 'services/user.service';
import { UserExplorationPermissionsService } from
  'pages/exploration-editor-page/services/user-exploration-permissions.service';
import { UtilsService } from 'services/utils.service';
import { ValidatorsService } from 'services/validators.service';
import { VersionTreeService } from
  'pages/exploration-editor-page/history-tab/services/version-tree.service';
import { VoiceoverBackendApiService } from 'domain/voiceover/voiceover-backend-api.service';
import { WindowDimensionsService } from
  'services/contextual/window-dimensions.service';
import { WindowRef } from 'services/contextual/window-ref.service';
import { WinnowingPreprocessingService } from
  'classifiers/winnowing-preprocessing.service';
import { WrittenTranslationObjectFactory } from
  'domain/exploration/WrittenTranslationObjectFactory';
import { WrittenTranslationsObjectFactory } from
  'domain/exploration/WrittenTranslationsObjectFactory';
import { SolutionVerificationService } from
  // eslint-disable-next-line max-len
  'pages/exploration-editor-page/editor-tab/services/solution-verification.service';
import { ResponsesService } from
  'pages/exploration-editor-page/editor-tab/services/responses.service';
import { QuestionValidationService } from './question-validation.service';
import { MathInteractionsService } from './math-interactions.service';

interface UpgradedServicesDict {
  // Type 'unknown' is used here because we don't know the exact type of
  // the service. We are using 'unknown' because we want to avoid using
  // 'any' as it is not type safe.
  [service: string]: unknown;
}
@Injectable({
  providedIn: 'root'
})
export class UpgradedServices {
  getUpgradedServices(): UpgradedServicesDict {
    var upgradedServices = {};
    // We are using eslint disable here for multilines because we have not used
    // dot notation at a lot of places so it does not seem practical to use
    // "eslint disable next line" for each of them. Also, we can't use dot
    // notation either because then "Property 'AdminRouterService' does not
    // exist on type '{}'" lint error will be raised by the linter.
    /* eslint-disable-next-line oppia/no-multiline-disable */
    /* eslint-disable dot-notation */

    // Topological level: 0.
    upgradedServices['AdminRouterService'] = new AdminRouterService();
    upgradedServices['AdminTaskManagerService'] = new AdminTaskManagerService();
    upgradedServices['AlgebraicExpressionInputRulesService'] =
      new AlgebraicExpressionInputRulesService(
        new MathInteractionsService(),
        new NumericExpressionInputRulesService());
    upgradedServices['AngularNameService'] = new AngularNameService();
    upgradedServices['AppService'] = new AppService();
    upgradedServices['AudioBarStatusService'] = new AudioBarStatusService();
    upgradedServices['AudioTranslationManagerService'] =
      new AudioTranslationManagerService();
    upgradedServices['AutoplayedVideosService'] = new AutoplayedVideosService();
    upgradedServices['BackgroundMaskService'] = new BackgroundMaskService();
    upgradedServices['baseInteractionValidationService'] =
      new baseInteractionValidationService();
    upgradedServices['BrowserCheckerService'] =
      new BrowserCheckerService(new WindowRef());
    upgradedServices['CamelCaseToHyphensPipe'] = new CamelCaseToHyphensPipe();
    upgradedServices['CodeNormalizerService'] = new CodeNormalizerService();
    upgradedServices['CollectionValidationService'] =
      new CollectionValidationService();
    upgradedServices['ComputeGraphService'] = new ComputeGraphService();
    upgradedServices['ConstructTranslationIdsService'] =
      new ConstructTranslationIdsService();
    upgradedServices['ContinueRulesService'] = new ContinueRulesService();
    upgradedServices['CountVectorizerService'] = new CountVectorizerService();
    upgradedServices['DateTimeFormatService'] = new DateTimeFormatService();
    upgradedServices['DragAndDropSortInputRulesService'] =
      new DragAndDropSortInputRulesService();
    upgradedServices['EditabilityService'] = new EditabilityService();
    upgradedServices['EndExplorationRulesService'] =
      new EndExplorationRulesService();
    upgradedServices['ExplorationDiffService'] = new ExplorationDiffService();
    upgradedServices['ExplorationFeaturesService'] =
      new ExplorationFeaturesService();
    upgradedServices['ExpressionParserService'] = new ExpressionParserService();
    upgradedServices['ExternalSaveService'] = new ExternalSaveService();
    upgradedServices['GraphDetailService'] = new GraphDetailService();
    upgradedServices['GraphUtilsService'] = new GraphUtilsService();
    upgradedServices['I18nLanguageCodeService'] = new I18nLanguageCodeService();
    upgradedServices['IdGenerationService'] = new IdGenerationService();
    upgradedServices['ImageClickInputRulesService'] =
      new ImageClickInputRulesService();
    upgradedServices['ImprovementsService'] = new ImprovementsService();
    upgradedServices['InteractionDetailsCacheService'] =
      new InteractionDetailsCacheService();
    upgradedServices['InteractiveMapRulesService'] =
      new InteractiveMapRulesService();
    upgradedServices['InteractionSpecsService'] = new InteractionSpecsService();
    upgradedServices['ItemSelectionInputRulesService'] =
      new ItemSelectionInputRulesService();
    upgradedServices['LearnerParamsService'] = new LearnerParamsService();
    upgradedServices['LoaderService'] = new LoaderService();
    upgradedServices['LoggerService'] = new LoggerService();
    upgradedServices['LostChangeObjectFactory'] = new LostChangeObjectFactory(
      new UtilsService);
    upgradedServices['MathEquationInputRulesService'] =
      new MathEquationInputRulesService(
        upgradedServices['AlgebraicExpressionInputRulesService']
      );
    upgradedServices['Meta'] = new Meta({});
    upgradedServices['MisconceptionObjectFactory'] =
      new MisconceptionObjectFactory();
    upgradedServices['MultipleChoiceInputRulesService'] =
      new MultipleChoiceInputRulesService();
    upgradedServices['MusicPhrasePlayerService'] =
      new MusicPhrasePlayerService();
    upgradedServices['NormalizeWhitespacePunctuationAndCasePipe'] =
      new NormalizeWhitespacePunctuationAndCasePipe();
    upgradedServices['NumberAttemptsService'] = new NumberAttemptsService();
    upgradedServices['NumericExpressionInputRulesService'] =
      new NumericExpressionInputRulesService();
    upgradedServices['NumericInputRulesService'] =
      new NumericInputRulesService();
    upgradedServices['ParamChangeObjectFactory'] =
      new ParamChangeObjectFactory();
    upgradedServices['ParamTypeObjectFactory'] = new ParamTypeObjectFactory();
    upgradedServices['RatingComputationService'] =
      new RatingComputationService();
    upgradedServices['RatioExpressionInputRulesService'] =
      new RatioExpressionInputRulesService();
    upgradedServices['ReviewTestEngineService'] = new ReviewTestEngineService();
    upgradedServices['SchemaFormSubmittedService'] =
      new SchemaFormSubmittedService();
    upgradedServices['SchemaUndefinedLastElementService'] =
      new SchemaUndefinedLastElementService();
    upgradedServices['SetInputRulesService'] = new SetInputRulesService();
    upgradedServices['SolutionValidityService'] = new SolutionValidityService();
    upgradedServices['StateEditorRefreshService'] =
      new StateEditorRefreshService();
    upgradedServices['StateGraphLayoutService'] = new StateGraphLayoutService();
    upgradedServices['StateNameService'] = new StateNameService();
    upgradedServices['SubtitledUnicodeObjectFactory'] =
      new SubtitledUnicodeObjectFactory();
    upgradedServices['SuggestionModalService'] = new SuggestionModalService();
    upgradedServices['SuggestionsService'] = new SuggestionsService();
    upgradedServices['TextInputTokenizer'] = new TextInputTokenizer();
    upgradedServices['ThreadStatusDisplayService'] =
      new ThreadStatusDisplayService();
    upgradedServices['Title'] = new Title({});
    upgradedServices['TopicsAndSkillsDashboardPageService'] =
        new TopicsAndSkillsDashboardPageService(
          upgradedServices['PlatformFeatureService']);
    upgradedServices['UnitsObjectFactory'] = new UnitsObjectFactory();
    upgradedServices['UtilsService'] = new UtilsService();
    upgradedServices['VersionTreeService'] = new VersionTreeService();
    upgradedServices['WindowRef'] = new WindowRef();
    upgradedServices['WinnowingPreprocessingService'] =
      new WinnowingPreprocessingService();
    upgradedServices['WrittenTranslationObjectFactory'] =
      new WrittenTranslationObjectFactory();
    upgradedServices['baseInteractionValidationService'] =
      new baseInteractionValidationService();
    upgradedServices['ɵangular_packages_common_http_http_d'] =
      new ɵangular_packages_common_http_http_d();

    // Topological level: 1.
    upgradedServices['AlgebraicExpressionInputValidationService'] =
      new AlgebraicExpressionInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['AlertsService'] = new AlertsService(
      upgradedServices['LoggerService']);
    upgradedServices['BrowserCheckerService'] = new BrowserCheckerService(
      upgradedServices['WindowRef']);
    upgradedServices['CodeReplValidationService'] =
      new CodeReplValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['ContinueValidationService'] =
      new ContinueValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['DeviceInfoService'] = new DeviceInfoService(
      upgradedServices['WindowRef']);
    upgradedServices['DocumentAttributeCustomizationService'] =
      new DocumentAttributeCustomizationService(upgradedServices['WindowRef']);
    upgradedServices['DragAndDropSortInputValidationService'] =
      new DragAndDropSortInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['EndExplorationValidationService'] =
      new EndExplorationValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['ExpressionSyntaxTreeService'] =
      new ExpressionSyntaxTreeService(
        upgradedServices['ExpressionParserService']);
    upgradedServices['FeedbackThreadObjectFactory'] =
      new FeedbackThreadObjectFactory();
    upgradedServices['FractionInputRulesService'] =
      new FractionInputRulesService(
        upgradedServices['UtilsService']);
    upgradedServices['FractionInputValidationService'] =
      new FractionInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['GraphInputRulesService'] =
      new GraphInputRulesService(
        upgradedServices['GraphUtilsService'],
        upgradedServices['UtilsService']);
    upgradedServices['GraphInputValidationService'] =
      new GraphInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['GuestCollectionProgressService'] =
      new GuestCollectionProgressService(
        upgradedServices['WindowRef']);
    upgradedServices['HtmlEscaperService'] = new HtmlEscaperService(
      upgradedServices['LoggerService']);
    upgradedServices['HttpXhrBackend'] = new HttpXhrBackend(
      upgradedServices['ɵangular_packages_common_http_http_d']);
    upgradedServices['ImageClickInputValidationService'] =
      new ImageClickInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['InteractiveMapValidationService'] =
      new InteractiveMapValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['ItemSelectionInputValidationService'] =
      new ItemSelectionInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['LocalStorageService'] = new LocalStorageService(
      upgradedServices['WindowRef']);
    upgradedServices['MathEquationInputValidationService'] =
      new MathEquationInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['MessengerService'] = new MessengerService(
      upgradedServices['LoggerService'],
      upgradedServices['WindowRef']);
    upgradedServices['MetaTagCustomizationService'] =
      new MetaTagCustomizationService(upgradedServices['WindowRef']);
    upgradedServices['MultipleChoiceInputValidationService'] =
      new MultipleChoiceInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['MusicNotesInputRulesService'] =
      new MusicNotesInputRulesService(
        upgradedServices['UtilsService']);
    upgradedServices['MusicNotesInputValidationService'] =
      new MusicNotesInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['NormalizeWhitespacePipe'] = new NormalizeWhitespacePipe(
      upgradedServices['UtilsService']);
    upgradedServices['NumericInputValidationService'] =
      new NumericInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['NumberWithUnitsObjectFactory'] =
      new NumberWithUnitsObjectFactory(
        upgradedServices['UnitsObjectFactory']);
    upgradedServices['NumericExpressionInputValidationService'] =
      new NumericExpressionInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['NumberWithUnitsRulesService'] =
      new NumberWithUnitsRulesService(
        upgradedServices['UnitsObjectFactory'],
        upgradedServices['UtilsService']);
    upgradedServices['OutcomeObjectFactory'] =
      new OutcomeObjectFactory();
    upgradedServices['PageTitleService'] = new PageTitleService(
      upgradedServices['Meta'], upgradedServices['Title']);
    upgradedServices['ParamChangesObjectFactory'] =
      new ParamChangesObjectFactory(
        upgradedServices['ParamChangeObjectFactory']);
    upgradedServices['ParamSpecObjectFactory'] = new ParamSpecObjectFactory(
      upgradedServices['ParamTypeObjectFactory']);
    upgradedServices['PencilCodeEditorValidationService'] =
      new PencilCodeEditorValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['PlayerTranscriptService'] = new PlayerTranscriptService(
      upgradedServices['LoggerService']);
    upgradedServices['PythonProgramTokenizer'] = new PythonProgramTokenizer(
      upgradedServices['LoggerService']);
    upgradedServices['ResponsesService'] =
      new ResponsesService(
        upgradedServices['AlertsService'],
        upgradedServices['LoggerService'],
        upgradedServices['OutcomeObjectFactory'],
        upgradedServices['SolutionValidityService'],
        upgradedServices['SolutionVerificationService'],
        upgradedServices['StateCustomizationArgsService'],
        upgradedServices['StateEditorService'],
        upgradedServices['StateInteractionIdService'],
        upgradedServices['StateSolutionService']
      );
    upgradedServices['QuestionValidationService'] =
      new QuestionValidationService(
        upgradedServices['ResponsesService'],
        upgradedServices['StateEditorService']
      );
    upgradedServices['RatioExpressionInputValidationService'] =
          new RatioExpressionInputValidationService(
            upgradedServices['baseInteractionValidationService']);
    upgradedServices['SetInputValidationService'] =
      new SetInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['SkillCreationBackendApiService'] =
        new SkillCreationBackendApiService(
          upgradedServices['HttpClient'],
          upgradedServices['ImageLocalStorageService']);
    upgradedServices['StateTopAnswersStatsObjectFactory'] =
        new StateTopAnswersStatsObjectFactory();
    upgradedServices['SpeechSynthesisChunkerService'] =
        new SpeechSynthesisChunkerService(
          upgradedServices['HtmlEscaperService']);
    upgradedServices['SVMPredictionService'] = new SVMPredictionService();
    upgradedServices['SchemaDefaultValueService'] =
      new SchemaDefaultValueService(
        upgradedServices['LoggerService'],
        upgradedServices['SubtitledUnicodeObjectFactory']);
    upgradedServices['SiteAnalyticsService'] = new SiteAnalyticsService(
      upgradedServices['WindowRef']);
    upgradedServices['StateEditorService'] = new StateEditorService(
      upgradedServices['SolutionValidityService']);
    upgradedServices['TextInputValidationService'] =
      new TextInputValidationService(
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['TopicCreationBackendApiService'] =
        new TopicCreationBackendApiService(
          upgradedServices['HttpClient']);
    upgradedServices['UrlService'] = new UrlService(
      upgradedServices['WindowRef']);
    upgradedServices['WindowDimensionsService'] = new WindowDimensionsService(
      upgradedServices['WindowRef']);
    upgradedServices['WrittenTranslationsObjectFactory'] =
      new WrittenTranslationsObjectFactory(
        upgradedServices['WrittenTranslationObjectFactory']);

    // Topological level: 2.
    upgradedServices['CsrfTokenService'] = new CsrfTokenService(
      upgradedServices['HttpXhrBackend']);
    upgradedServices['AnswerGroupObjectFactory'] = new AnswerGroupObjectFactory(
      upgradedServices['OutcomeObjectFactory']);
    upgradedServices['CkEditorCopyContentService'] =
      new CkEditorCopyContentService(
        upgradedServices['HtmlEscaperService']);
    upgradedServices['AutogeneratedAudioPlayerService'] =
      new AutogeneratedAudioPlayerService(
        upgradedServices['SpeechSynthesisChunkerService']);
    upgradedServices['BottomNavbarStatusService'] = (
      new BottomNavbarStatusService(
        upgradedServices['WindowDimensionsService']));
    upgradedServices['PreventPageUnloadEventService'] =
        new PreventPageUnloadEventService(upgradedServices['WindowRef']);
    upgradedServices['CodeReplRulesService'] = new CodeReplRulesService(
      upgradedServices['NormalizeWhitespacePipe'],
      upgradedServices['CodeNormalizerService']);
    upgradedServices['ContextService'] = new ContextService(
      upgradedServices['UrlService'],
      upgradedServices['BlogPostPageService']);
    upgradedServices['EditorFirstTimeEventsService'] =
      new EditorFirstTimeEventsService(
        upgradedServices['SiteAnalyticsService']);
    upgradedServices['ExplorationImprovementsTaskRegistryService'] =
      new ExplorationImprovementsTaskRegistryService();
    upgradedServices['ExpressionEvaluatorService'] =
      new ExpressionEvaluatorService(
        upgradedServices['ExpressionParserService'],
        upgradedServices['ExpressionSyntaxTreeService']);
    upgradedServices['ExtensionTagAssemblerService'] =
      new ExtensionTagAssemblerService(
        upgradedServices['HtmlEscaperService'],
        upgradedServices['CamelCaseToHyphensPipe']);
    upgradedServices['FocusManagerService'] = new FocusManagerService(
      upgradedServices['DeviceInfoService'],
      upgradedServices['IdGenerationService'],
      upgradedServices['WindowRef'],
    );
    upgradedServices['HttpClient'] = new HttpClient(
      upgradedServices['HttpXhrBackend']);
    upgradedServices['LanguageUtilService'] = new LanguageUtilService(
      upgradedServices['BrowserCheckerService']);
    upgradedServices['NumberWithUnitsValidationService'] =
      new NumberWithUnitsValidationService(
        upgradedServices['NumberWithUnitsObjectFactory'],
        upgradedServices['baseInteractionValidationService']);
    upgradedServices['ParamSpecsObjectFactory'] = new ParamSpecsObjectFactory(
      upgradedServices['ParamSpecObjectFactory']);
    upgradedServices['PencilCodeEditorRulesService'] =
      new PencilCodeEditorRulesService(
        upgradedServices['NormalizeWhitespacePipe'],
        upgradedServices['NormalizeWhitespacePunctuationAndCasePipe'],
        upgradedServices['CodeNormalizerService']);
    upgradedServices['SidebarStatusService'] = new SidebarStatusService(
      upgradedServices['WindowDimensionsService']);
    upgradedServices['StateContentService'] = new StateContentService(
      upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateCustomizationArgsService'] =
      new StateCustomizationArgsService(
        upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateHintsService'] = new StateHintsService(
      upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateInteractionIdService'] =
      new StateInteractionIdService(
        upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StatePropertyService'] = new StatePropertyService(
      upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateRecordedVoiceoversService'] =
      new StateRecordedVoiceoversService(
        upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateSolicitAnswerDetailsService'] =
      new StateSolicitAnswerDetailsService(
        upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateSolutionService'] = new StateSolutionService(
      upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StateWrittenTranslationsService'] =
      new StateWrittenTranslationsService(
        upgradedServices['AlertsService'], upgradedServices['UtilsService']);
    upgradedServices['StoryEditorNavigationService'] =
        new StoryEditorNavigationService(upgradedServices['WindowRef']);
    upgradedServices['TextInputRulesService'] = new TextInputRulesService(
      upgradedServices['NormalizeWhitespacePipe']);
    upgradedServices['UrlInterpolationService'] = new UrlInterpolationService(
      upgradedServices['AlertsService'], upgradedServices['UrlService'],
      upgradedServices['UtilsService']);
    upgradedServices['ValidatorsService'] = new ValidatorsService(
      upgradedServices['AlertsService'],
      upgradedServices['NormalizeWhitespacePipe']);

    // Topological level: 3.
    upgradedServices['AdminBackendApiService'] = new AdminBackendApiService(
      upgradedServices['HttpClient'],
      upgradedServices['UrlInterpolationService']);
    upgradedServices['AdminDataService'] = new AdminDataService(
      upgradedServices['HttpClient']);
    upgradedServices['AssetsBackendApiService'] =
      new AssetsBackendApiService(
        upgradedServices['CsrfTokenService'],
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['EmailDashboardBackendApiService'] =
      new EmailDashboardBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['ExplorationPermissionsBackendApiService'] =
      new ExplorationPermissionsBackendApiService(
        upgradedServices['ContextService'],
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ExplorationRecommendationsBackendApiService'] =
      new ExplorationRecommendationsBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['InteractionRulesRegistryService'] =
      new InteractionRulesRegistryService(
        upgradedServices['AlgebraicExpressionInputRulesService'],
        upgradedServices['CodeReplRulesService'],
        upgradedServices['ContinueRulesService'],
        upgradedServices['DragAndDropSortInputRulesService'],
        upgradedServices['EndExplorationRulesService'],
        upgradedServices['FractionInputRulesService'],
        upgradedServices['GraphInputRulesService'],
        upgradedServices['ImageClickInputRulesService'],
        upgradedServices['InteractiveMapRulesService'],
        upgradedServices['ItemSelectionInputRulesService'],
        upgradedServices['MathEquationInputRulesService'],
        upgradedServices['MultipleChoiceInputRulesService'],
        upgradedServices['MusicNotesInputRulesService'],
        upgradedServices['NumberWithUnitsRulesService'],
        upgradedServices['NumericExpressionInputRulesService'],
        upgradedServices['NumericInputRulesService'],
        upgradedServices['PencilCodeEditorRulesService'],
        upgradedServices['RatioExpressionInputRulesService'],
        upgradedServices['SetInputRulesService'],
        upgradedServices['TextInputRulesService']);
    upgradedServices['AudioTranslationLanguageService'] =
      new AudioTranslationLanguageService(
        upgradedServices['BrowserCheckerService'],
        upgradedServices['LanguageUtilService']);
    upgradedServices['ConceptCardBackendApiService'] =
      new ConceptCardBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ClassifierDataBackendApiService'] =
      new ClassifierDataBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ClassroomBackendApiService'] =
      new ClassroomBackendApiService(
        upgradedServices['UrlInterpolationService'],
        upgradedServices['HttpClient']);
    upgradedServices['CollectionCreationBackendService'] = (
      new CollectionCreationBackendService(
        upgradedServices['HttpClient']));
    upgradedServices['CollectionRightsBackendApiService'] =
      new CollectionRightsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ContributionOpportunitiesBackendApiService'] =
      new ContributionOpportunitiesBackendApiService(
        upgradedServices['UrlInterpolationService'],
        upgradedServices['HttpClient'],
        upgradedServices['UserService']);
    upgradedServices['CreatorDashboardBackendApiService'] =
      new CreatorDashboardBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['FeedbackThreadObjectFactory'],
        upgradedServices['SuggestionsService'],
        upgradedServices['LoggerService']);
    upgradedServices['CurrentInteractionService'] =
      new CurrentInteractionService(
        upgradedServices['ContextService'],
        upgradedServices['PlayerPositionService'],
        upgradedServices['PlayerTranscriptService']);
    upgradedServices['ExplorationFeaturesBackendApiService'] =
      new ExplorationFeaturesBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ExplorationHtmlFormatterService'] =
      new ExplorationHtmlFormatterService(
        upgradedServices['CamelCaseToHyphensPipe'],
        upgradedServices['ExtensionTagAssemblerService'],
        upgradedServices['HtmlEscaperService']);
    upgradedServices['ExplorationImprovementsBackendApiService'] =
      new ExplorationImprovementsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ExplorationStatsBackendApiService'] =
      new ExplorationStatsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['LearnerAnswerDetailsBackendApiService'] =
        new LearnerAnswerDetailsBackendApiService(
          upgradedServices['HttpClient'],
          upgradedServices['UrlInterpolationService']);
    upgradedServices['LearnerDashboardBackendApiService'] =
      new LearnerDashboardBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['LearnerDashboardIdsBackendApiService'] =
        new LearnerDashboardIdsBackendApiService(
          upgradedServices['HttpClient']);
    upgradedServices['FeatureFlagBackendApiService'] =
      new FeatureFlagBackendApiService(
        upgradedServices['HttpClient']
      );
    upgradedServices['PlatformParameterAdminBackendApiService'] =
      new PlatformParameterAdminBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['FeatureFlagDummyBackendApiService'] =
      new FeatureFlagDummyBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['PlayerPositionService'] = new PlayerPositionService(
      upgradedServices['PlayerTranscriptService']);
    upgradedServices['PlaythroughBackendApiService'] =
      new PlaythroughBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['PlaythroughIssuesBackendApiService'] =
      new PlaythroughIssuesBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ProfilePageBackendApiService'] =
      new ProfilePageBackendApiService(
        upgradedServices['UrlInterpolationService'],
        upgradedServices['HttpClient'],
        upgradedServices['UrlService'],
        upgradedServices['UserService']);
    upgradedServices['QuestionBackendApiService'] =
      new QuestionBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService'],
        upgradedServices['QuestionObjectFactory']);
    upgradedServices['ReadOnlyCollectionBackendApiService'] =
      new ReadOnlyCollectionBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ReadOnlyTopicObjectFactory'] =
      new ReadOnlyTopicObjectFactory();
    upgradedServices['ReviewTestBackendApiService'] =
      new ReviewTestBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService'],
        upgradedServices['UrlService']);
    upgradedServices['SearchExplorationsBackendApiService'] =
      new SearchExplorationsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['SolutionVerificationService'] =
      new SolutionVerificationService(
        upgradedServices['InteractionRulesRegistryService'],
        upgradedServices['AnswerClassificationService'],
        upgradedServices['StateEditorService']);
    upgradedServices['SkillCreationBackendApiService'] =
      new SkillCreationBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['ImageLocalStorageService']);
    upgradedServices['SkillMasteryBackendApiService'] =
      new SkillMasteryBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['SkillObjectFactory'] =
      new SkillObjectFactory(
        upgradedServices['MisconceptionObjectFactory'],
        upgradedServices['ValidatorsService']);
    upgradedServices['SkillRightsBackendApiService'] =
      new SkillRightsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['StateClassifierMappingService'] =
      new StateClassifierMappingService(
        upgradedServices['AppService'],
        upgradedServices['ClassifierDataBackendApiService'],
        upgradedServices['LoggerService']);
    upgradedServices['StateInteractionStatsBackendApiService'] =
      new StateInteractionStatsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['StateParamChangesService'] =
      new StateParamChangesService(
        upgradedServices['AlertsService'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['StateTopAnswersStatsBackendApiService'] =
      new StateTopAnswersStatsBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['StateTopAnswersStatsObjectFactory'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['StatsReportingBackendApiService'] =
      new StatsReportingBackendApiService(
        upgradedServices['ContextService'],
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['StoryViewerBackendApiService'] =
        new StoryViewerBackendApiService(
          upgradedServices['HttpClient'],
          upgradedServices['UrlInterpolationService']);
    upgradedServices['TextInputPredictionService'] =
      new TextInputPredictionService(
        upgradedServices['CountVectorizerService'],
        upgradedServices['SVMPredictionService'],
        upgradedServices['TextInputTokenizer']);
    upgradedServices['TopicCreationBackendApiService'] =
      new TopicCreationBackendApiService(upgradedServices['HttpClient']);
    upgradedServices['TopicsAndSkillsDashboardBackendApiService'] =
      new TopicsAndSkillsDashboardBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['TopicViewerBackendApiService'] =
      new TopicViewerBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['UserBackendApiService'] =
      new UserBackendApiService(
        upgradedServices['HttpClient']);
    upgradedServices['UserService'] = new UserService(
      upgradedServices['AssetsBackendApiService'],
      upgradedServices['ImageLocalStorageService'],
      upgradedServices['UrlInterpolationService'],
      upgradedServices['UrlService'],
      upgradedServices['WindowRef'],
      upgradedServices['UserBackendApiService']
    );
    upgradedServices['VoiceoverBackendApiService'] =
      new VoiceoverBackendApiService(
        upgradedServices['UrlInterpolationService'],
        upgradedServices['HttpClient']);

    // Topological level: 4.
    upgradedServices['CollectionCreationService'] =
      new CollectionCreationService(
        upgradedServices['CollectionCreationBackendService'],
        upgradedServices['AlertsService'],
        upgradedServices['SiteAnalyticsService'],
        upgradedServices['UrlInterpolationService'],
        upgradedServices['LoaderService'],
        upgradedServices['WindowRef']);
    upgradedServices['EditableCollectionBackendApiService'] =
      new EditableCollectionBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['ReadOnlyCollectionBackendApiService'],
        upgradedServices['UrlInterpolationService']);
    upgradedServices['ExplorationRecommendationsService'] =
      new ExplorationRecommendationsService(
        upgradedServices['ContextService'],
        upgradedServices['UrlService'],
        upgradedServices['ExplorationRecommendationsBackendApiService']);
    upgradedServices['ExplorationStatsService'] = new ExplorationStatsService(
      upgradedServices['ExplorationStatsBackendApiService']);
    upgradedServices['ExtensionTagAssemblerService'] =
      new ExtensionTagAssemblerService(
        upgradedServices['HtmlEscaperService'],
        upgradedServices['CamelCaseToHyphensPipe']);
    upgradedServices['PlatformFeatureService'] = new PlatformFeatureService(
      upgradedServices['FeatureFlagBackendApiService'],
      upgradedServices['WindowRef'],
      upgradedServices['LoggerService'],
      upgradedServices['UrlService']);
    upgradedServices['PopulateRuleContentIdsService'] =
      new PopulateRuleContentIdsService(
        upgradedServices['GenerateContentIdService']);
    upgradedServices['PredictionAlgorithmRegistryService'] =
      new PredictionAlgorithmRegistryService(
        upgradedServices['TextInputPredictionService']);
    upgradedServices['UserExplorationPermissionsService'] = (
      new UserExplorationPermissionsService(
        upgradedServices['ExplorationPermissionsBackendApiService']));
    upgradedServices['SubtopicViewerBackendApiService'] =
      new SubtopicViewerBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);

    // Topological level: 5.
    upgradedServices['AnswerClassificationService'] =
      new AnswerClassificationService(
        upgradedServices['AlertsService'],
        upgradedServices['AppService'],
        upgradedServices['InteractionSpecsService'],
        upgradedServices['PredictionAlgorithmRegistryService'],
        upgradedServices['StateClassifierMappingService']);
    upgradedServices['AudioPreloaderService'] = new AudioPreloaderService(
      upgradedServices['AssetsBackendApiService'],
      upgradedServices['AudioTranslationLanguageService'],
      upgradedServices['ComputeGraphService'],
      upgradedServices['ContextService']);
    upgradedServices['ExplorationHtmlFormatterService'] =
      new ExplorationHtmlFormatterService(
        upgradedServices['CamelCaseToHyphensPipe'],
        upgradedServices['ExtensionTagAssemblerService'],
        upgradedServices['HtmlEscaperService']);
    upgradedServices['SubtopicViewerBackendApiService'] =
      new SubtopicViewerBackendApiService(
        upgradedServices['HttpClient'],
        upgradedServices['UrlInterpolationService']);

    // Topological level: 6.
    upgradedServices['SolutionObjectFactory'] = new SolutionObjectFactory(
      upgradedServices['ExplorationHtmlFormatterService']);
    upgradedServices['StateInteractionStatsService'] =
      new StateInteractionStatsService(
        upgradedServices['AnswerClassificationService'],
        upgradedServices['InteractionRulesRegistryService'],
        upgradedServices['StateInteractionStatsBackendApiService']);
    upgradedServices['StateTopAnswersStatsService'] =
      new StateTopAnswersStatsService(
        upgradedServices['AnswerClassificationService'],
        upgradedServices['InteractionRulesRegistryService'],
        upgradedServices['StateTopAnswersStatsBackendApiService']);

    // Topological level: 7.
    upgradedServices['InteractionObjectFactory'] = new InteractionObjectFactory(
      upgradedServices['AnswerGroupObjectFactory'],
      upgradedServices['SolutionObjectFactory'],
      upgradedServices['OutcomeObjectFactory'],
      upgradedServices['SubtitledUnicodeObjectFactory']);

    // Topological level: 8.
    upgradedServices['InteractionAttributesExtractorService'] =
      new InteractionAttributesExtractorService(
        upgradedServices['HtmlEscaperService'],
        upgradedServices['InteractionObjectFactory']);
    upgradedServices['StateObjectFactory'] = new StateObjectFactory(
      upgradedServices['InteractionObjectFactory'],
      upgradedServices['ParamChangesObjectFactory']);

    // Topological level: 9.
    upgradedServices['StatesObjectFactory'] = new StatesObjectFactory(
      upgradedServices['StateObjectFactory']);
    upgradedServices['QuestionObjectFactory'] = new QuestionObjectFactory(
      upgradedServices['StateObjectFactory']);

    // Topological level: 10.
    upgradedServices['ExplorationObjectFactory'] = new ExplorationObjectFactory(
      upgradedServices['LoggerService'],
      upgradedServices['ParamChangesObjectFactory'],
      upgradedServices['ParamSpecsObjectFactory'],
      upgradedServices['StatesObjectFactory'],
      upgradedServices['UrlInterpolationService']);
    upgradedServices['PretestQuestionBackendApiService'] =
      new PretestQuestionBackendApiService(
        upgradedServices['UrlInterpolationService'],
        upgradedServices['HttpClient'],
        upgradedServices['QuestionObjectFactory']);

    /* eslint-enable dot-notation */
    return upgradedServices;
  }
}

angular.module('oppia').factory(
  'UpgradedServices',
  downgradeInjectable(UpgradedServices));
